searchNodes=[{"ref":"EctoResource.html","title":"EctoResource","type":"module","doc":"This module represents the generic CRUD functionality that is boilerplate within Phoenix context files. It provides a DSL to easily generate the basic functions for a schema. This allows the context to focus on interesting, atypical implementations rather than the redundent, drifting crud functions."},{"ref":"EctoResource.html#all/3","title":"EctoResource.all/3","type":"function","doc":"Returns a list of all the records for a given Schema. Examples iex&gt; all(Repo, User) [ %User{ __meta__: #Ecto.Schema.Metadata&lt;:loaded, &quot;users&quot;&gt;, id: 1, inserted_at: ~N[2019-08-15 18:52:50], email: &quot;example@example.com&quot;, updated_at: ~N[2019-08-15 18:52:50] } ]"},{"ref":"EctoResource.html#change/2","title":"EctoResource.change/2","type":"function","doc":"Creates a changeset for a given Schema iex&gt; change(%User{email: &quot;user@example.com&quot;}, %{email: &quot;updated-email@example.com&quot;}) #Ecto.Changeset&lt; action: nil, changes: %{}, errors: [], data: #Engine.BusinessPartners.BusinessPartner&lt;&gt;, valid?: true &gt;"},{"ref":"EctoResource.html#create/3","title":"EctoResource.create/3","type":"function","doc":"Creates a new record with the given changeset Examples iex&gt; create(Repo, User, %{email: &quot;user@example.com&quot;}) {:ok, %User{ __meta__: #Ecto.Schema.Metadata&lt;:loaded, &quot;users&quot;&gt;, inserted_at: ~N[2019-08-17 00:41:41], email: &quot;example@example.com&quot;, updated_at: ~N[2019-08-17 00:41:41] }}"},{"ref":"EctoResource.html#delete/2","title":"EctoResource.delete/2","type":"function","doc":"Deletes a given Schema struct Examples iex&gt; delete(Repo, %User{id: 1}) {:ok, %User{ __meta__: #Ecto.Schema.Metadata&lt;:deleted, &quot;users&quot;&gt;, id: 1, inserted_at: ~N[2019-08-17 00:41:41], email: &quot;example@example.com&quot;, updated_at: ~N[2019-08-17 00:41:41] }}"},{"ref":"EctoResource.html#get/4","title":"EctoResource.get/4","type":"function","doc":"Gets a Schema struct by the given id. Can also take options to alter the resulting query. Examples iex&gt; get(Repo, User, 1) %User{ __meta__: #Ecto.Schema.Metadata&lt;:loaded, &quot;users&quot;&gt;, id: 1, inserted_at: ~N[2019-08-15 18:52:50], email: &quot;example@example.com&quot;, updated_at: ~N[2019-08-15 18:52:50] }"},{"ref":"EctoResource.html#resource/2","title":"EctoResource.resource/2","type":"macro","doc":""},{"ref":"EctoResource.html#resource_actions/2","title":"EctoResource.resource_actions/2","type":"function","doc":"Return a map of actions with the function names, descriptions Examples iex&gt; resource_actions(&quot;_suffix&quot;, only: [:change]) %{ change: %{ name: :change_suffix, description: &quot;change_suffix/1&quot; } } iex&gt; resource_actions(&quot;_suffix&quot;, except: [:change]) %{ all: %{ name: :all_suffix, description: &quot;all_suffix/1&quot; }, create: %{ name: :create_suffix, description: &quot;create_suffix/1&quot; }, delete: %{ name: :delete_suffix, description: &quot;delete_suffix/1&quot; }, get: %{ name: :get_suffix, description: &quot;get_suffix/2&quot; }, update: %{ name: :update_suffix, description: &quot;update_suffix/2&quot; } } iex&gt; resource_actions(&quot;_suffix&quot;, :read) %{ all: %{ name: :all_suffix, description: &quot;all_suffix/1&quot; }, get: %{ name: :get_suffix, description: &quot;get_suffix/2&quot; } } iex&gt; resource_actions(&quot;_suffix&quot;, :write) %{ change: %{ name: :change_suffix, description: &quot;change_suffix/1&quot; }, create: %{ name: :create_suffix, description: &quot;create_suffix/1&quot; }, update: %{ name: :update_suffix, description: &quot;update_suffix/2&quot; } } iex&gt; resource_actions(&quot;_suffix&quot;, :delete) %{ delete: %{ name: :delete_suffix, description: &quot;delete_suffix/1&quot; } }"},{"ref":"EctoResource.html#underscore_module_name/1","title":"EctoResource.underscore_module_name/1","type":"function","doc":"Get an underscored module name for use in generating functions. Examples iex&gt; underscore_module_name(User) &quot;user&quot;"},{"ref":"EctoResource.html#update/4","title":"EctoResource.update/4","type":"function","doc":"Updates a given Schema with the given attributes Examples iex&gt; update(Repo, User, %User{id: 1}, %{email: &quot;updated@example.com&quot;}) {:ok, %User{ __meta__: #Ecto.Schema.Metadata&lt;:loaded, &quot;users&quot;&gt;, id: 1, inserted_at: ~N[2019-08-15 18:52:50], email: &quot;updated@example.com&quot;, updated_at: ~N[2019-08-17 01:16:01] }}"},{"ref":"EctoResource.html#using_repo/2","title":"EctoResource.using_repo/2","type":"macro","doc":""},{"ref":"Mix.Tasks.EctoResource.Resources.html","title":"Mix.Tasks.EctoResource.Resources","type":"task","doc":"Task to list the resources defined by EctoResource within a context module. $ mix ecto_resource.resources MyApp.MyContext"},{"ref":"Mix.Tasks.EctoResource.Resources.html#run/1","title":"Mix.Tasks.EctoResource.Resources.run/1","type":"function","doc":"A task needs to implement run which receives a list of command line args. Callback implementation for Mix.Task.run/1."},{"ref":"readme.html","title":"EctoResource","type":"extras","doc":"EctoResource Eliminate boilerplate involved in defining basic CRUD functions in a Phoenix context or Elixir module."},{"ref":"readme.html#installation","title":"EctoResource - Installation","type":"extras","doc":"If available in Hex, the package can be installed by adding ecto_resource to your list of dependencies in mix.exs: def deps do [ {:ecto_resource, &quot;~&gt; 0.1.0&quot;} ] end"},{"ref":"readme.html#basic-usage","title":"EctoResource - Basic Usage","type":"extras","doc":"All examples are using Accounts. This can be substituted for a Phoenix context or any other module. defmodule MyApp.Accounts do use EctoResource using_repo(MyApp.Repo) do resource(MyApp.User) end end This will generate the functions: def create_user(attributes) do EctoResource.create(MyApp.Repo, MyApp.User, attributes) end def all_users(options) do EctoResource.all(MyApp.Repo, MyApp.User, options) end def get_user(id, options) do EctoResource.get(MyApp.Repo, MyApp.User, id, options) end def change_user(struct_or_changeset) do EctoResource.change(MyApp.User, struct_or_changeset) end def update_user(%MyApp.User{id: 1}, changeset) do EctoResource.update(MyApp.Repo, MyApp.User, struct, changeset) end def delete_user(struct_or_changeset) do EctoResource.delete(MyApp.Repo, struct_or_changeset) end There are also introspection functions to understand what is generated by the macro MyApp.Accounts.__resource__(:resources) == [ {MyApp.Repo, MyApp.User, [ &quot;all_users/1&quot;, &quot;change_user/1&quot;, &quot;create_user/1&quot;, &quot;delete_user/1&quot;, &quot;get_user/2&quot;, &quot;update_user/2&quot; ]} ]"},{"ref":"readme.html#advanced-usage","title":"EctoResource - Advanced usage","type":"extras","doc":"More granular control is available through options"},{"ref":"readme.html#read-option","title":"EctoResource - :read option","type":"extras","doc":"defmodule MyApp.Accounts do use EctoResource using_repo(MyApp.Repo) do resource(User, :read) end end This will generate the functions: def all_users(options) do EctoResource.all(MyApp.Repo, MyApp.User, options) end def get_user(id, options) do EctoResource.get(MyApp.Repo, MyApp.User, id, options) end There are also introspection functions to understand what is generated by the macro MyApp.Accounts.__resource__(:resources) == [ {MyApp.Repo, MyApp.User, [ &quot;all_users/1&quot;, &quot;get_user/2&quot; ]} ]"},{"ref":"readme.html#write-option","title":"EctoResource - :write option","type":"extras","doc":"defmodule MyApp.Accounts do use EctoResource using_repo(MyApp.Repo) do resource(User, :write) end end This will generate the functions: def create_user(attributes) do EctoResource.create(MyApp.Repo, MyApp.User, attributes) end def change_user(struct_or_changeset) do EctoResource.change(MyApp.User, struct_or_changeset) end def update_user(%MyApp.User{id: 1}, changeset) do EctoResource.update(MyApp.Repo, MyApp.User, struct, changeset) end There are also introspection functions to understand what is generated by the macro MyApp.Accounts.__resource__(:resources) == [ {MyApp.Repo, MyApp.User, [ &quot;change_user/1&quot;, &quot;create_user/1&quot;, &quot;update_user/2&quot; ]} ]"},{"ref":"readme.html#delete-option","title":"EctoResource - :delete option","type":"extras","doc":"defmodule MyApp.Accounts do use EctoResource using_repo(MyApp.Repo) do resource(User, :delete) end end This will generate the functions: def delete_user(struct_or_changeset) do EctoResource.delete(MyApp.Repo, struct_or_changeset) end There are also introspection functions to understand what is generated by the macro MyApp.Accounts.__resource__(:resources) == [ {MyApp.Repo, MyApp.User, [ &quot;delete_user/1&quot; ]} ] Documentation can be generated with ExDoc and published on HexDocs. Once published, the docs can be found at https://hexdocs.pm/ecto_resource."}]